==> cn-tenfell-tools-nocontroller-1.0.7-sources.jar: cn/tenfell/tools/nocontroller/utils/ToolsUtils.java <==
package cn.tenfell.tools.nocontroller.utils;

import cn.tenfell.tools.nocontroller.annotation.InterfaceDoc;
import cn.tenfell.tools.nocontroller.annotation.InterfaceModule;
import cn.tenfell.tools.nocontroller.utilsentity.*;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.text.SimpleDateFormat;
import java.util.*;

public class ToolsUtils {
    public static List<InterfaceDocEntity> interfaceList = new ArrayList<InterfaceDocEntity>();
    public static String interfaceCreateTime;
    public static boolean isEmpty(final CharSequence cs){
        int strLen;
        if (cs != null && (strLen = cs.length()) != 0) {
            for(int i = 0; i < strLen; ++i) {
                if (!Character.isWhitespace(cs.charAt(i))) {
                    return false;
                }
            }
            return true;
        } else {
            return true;
        }
    }
    public static boolean equals(String str1, String str2) {
        return str1 == null ? str2 == null : str1.equals(str2);
    }
    public static boolean isArray(Object obj) {
        return obj != null && obj.getClass().isArray();
    }
    public static boolean isCollection(Object obj) {
        return obj != null && obj instanceof Collection;
    }
    public static boolean isMap(Object obj) {
        return obj != null && obj instanceof Map;
    }
    public static boolean isNumber(Object obj) {
        return (obj == null || obj.getClass() != Byte.TYPE) && (obj == null || obj.getClass() != Short.TYPE) && (obj == null || obj.getClass() != Integer.TYPE) && (obj == null || obj.getClass() != Long.TYPE) && (obj == null || obj.getClass() != Float.TYPE) && (obj == null || obj.getClass() != Double.TYPE) ? obj instanceof Number : true;
    }
    public static boolean isString(Object obj) {
        return obj instanceof String || obj instanceof Character;
    }
    public static boolean isBoolean(Object obj) {
        return obj instanceof Boolean || obj != null && obj.getClass() == Boolean.TYPE;
    }
    public static String toJsonString(Object object){
        StringBuffer sb = new StringBuffer();
        try{
            toJsonString(object,sb);
            return sb.toString();
        }catch (Exception e){
            e.printStackTrace();
            return "null";
        }
    }
    private static void toJsonString(Object object,StringBuffer sb) throws IllegalAccessException {
        if(object == null){
            sb.append("null");
            return;
        }
        if(isArray(object)){
            Object[] arr = (Object[])object;
            sb.append("[");
            for(int i=0;i<arr.length;i++){
                toJsonString(arr[i],sb);
                if(i<arr.length-1){
                    sb.append(",");
                }
            }
            sb.append("]");
        }else if(isCollection(object)){
            Collection coll = (Collection)object;
            int size = coll.size();
            int i = 0;
            Iterator it = coll.iterator();
            sb.append("[");
            while(it.hasNext()){
                i++;
                toJsonString(it.next(),sb);
                if(i<size){
                    sb.append(",");
                }
            }
            sb.append("]");
        }else if(isMap(object)){
            Map map = (Map)object;
            Set set = map.keySet();
            int size = set.size();
            int i = 0;
            sb.append("{");
            for(Object key:set){
                i++;
                sb.append("\"").append(key.toString()).append("\"").append(":");
                Object val = map.get(key);
                if(val != null && isString(val)){
                    sb.append("\"");
                }
                toJsonString(val,sb);
                if(val != null && isString(val)){
                    sb.append("\"");
                }
                if(i<size){
                    sb.append(",");
                }
            }
            sb.append("}");
        }else if(isString(object) || isBoolean(object) || isNumber(object)){
            //val
            sb.append(object.toString());
        }else{
            Field[] fields = object.getClass().getDeclaredFields();
            sb.append("{");
            boolean hasPoint= false;
            for(Field field:fields){
                int mod = field.getModifiers();
                if (Modifier.isStatic(mod) || Modifier.isFinal(mod)) {
                    continue;
                }
                field.setAccessible(true);
                sb.append("\"").append(field.getName()).append("\"").append(":");
                Object value = field.get(object);
                if(value != null && isString(value)){
                    sb.append("\"");
                }
                toJsonString(value,sb);
                if(value != null && isString(value)){
                    sb.append("\"");
                }
                sb.append(",");
                hasPoint = true;
            }
            if (hasPoint){
               sb.delete(sb.length()-1,sb.length());
            }
            sb.append("}");
        }
    }
    public static void setInterfaceList(List<ServiceCacheData> list){
        String[] conMappings = {"json","jsonp"};
        for(ServiceCacheData serviceCacheData:list){
            InterfaceDocEntity interfaceDocEntity = null;
            List<InterfaceDocChild> interfaceDocChildren = null;
            Object service = serviceCacheData.getService();
            List<Method> methodList = serviceCacheData.getMethods();
            for(Method method:methodList){
                Class<?>[] types = method.getParameterTypes();
                InterfaceDoc interfaceDoc = method.getAnnotation(InterfaceDoc.class);
                boolean hasDoc = interfaceDoc != null && (types.length == 1 && types[0] == PoData.class) || (types.length == 2 && types[0] == HttpServletRequest.class && types[1] == HttpServletResponse.class);
                if(!hasDoc){
                    continue;
                }
                if(interfaceDocEntity == null){
                    interfaceDocEntity = new InterfaceDocEntity();
                    interfaceDocChildren = new ArrayList<InterfaceDocChild>();
                    String moduleName = serviceCacheData.getServiceName();
                    InterfaceModule interfaceModule = service.getClass().getAnnotation(InterfaceModule.class);
                    if(interfaceModule != null && !"".equals(interfaceModule.value())){
                        moduleName = interfaceModule.value();
                    }
                    interfaceDocEntity.setName(moduleName);
                }
                InterfaceDocChild interfaceDocChild = new InterfaceDocChild();
                try{
                    Object returnObj = method.getReturnType().newInstance();
                    interfaceDocChild.setReturnData(ToolsUtils.toJsonString(returnObj));
                }catch (Exception e){
                }
                String interfaceName = method.getName();
                if(interfaceDoc != null && !"".equals(interfaceDoc.name())){
                    interfaceName = interfaceDoc.name();
                }
                interfaceDocChild.setName(interfaceName);
                List<InterfaceParams> interfaceParamsList = new ArrayList<InterfaceParams>();
                String[] params = interfaceDoc.params();
                for(String param:params){
                    String[] paramValues = param.split(interfaceDoc.separator(),3);
                    InterfaceParams interfaceParams = new InterfaceParams();
                    interfaceParams.setParam(paramValues[0]);
                    interfaceParams.setIsNeed(paramValues[1]);
                    interfaceParams.setParamDesc(paramValues[2]);
                    interfaceParamsList.add(interfaceParams);
                }
                interfaceDocChild.setParams(interfaceParamsList);
                List<String> urlList = new ArrayList<String>();
                if(types.length == 1 && types[0] == PoData.class){
                    //表示要处理的json,jsonp
                    for(String conMapping:conMappings){
                        String mapKey = "/"+conMapping+"/"+serviceCacheData.getServiceName()+"/"+method.getName();
                        urlList.add(mapKey);
                    }
                }else if(types.length == 2 && types[0] == HttpServletRequest.class && types[1] == HttpServletResponse.class){
                    //表示要处理的selevt
                    String mapKey = "/selevt/"+serviceCacheData.getServiceName()+"/"+method.getName();
                    urlList.add(mapKey);
                }
                interfaceDocChild.setUrlList(urlList);
                interfaceDocChildren.add(interfaceDocChild);
            }
            if(interfaceDocEntity != null){
                interfaceDocEntity.setList(interfaceDocChildren);
                interfaceList.add(interfaceDocEntity);
            }
        }
        interfaceCreateTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date());
    }
}

==> cn-tenfell-tools-nocontroller-1.1.7-sources.jar: cn/tenfell/tools/nocontroller/utils/ToolsUtils.java <==
package cn.tenfell.tools.nocontroller.utils;

import cn.hutool.core.exceptions.ExceptionUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.extra.servlet.ServletUtil;
import cn.hutool.json.JSONUtil;
import cn.tenfell.tools.nocontroller.annotation.InterfaceDoc;
import cn.tenfell.tools.nocontroller.annotation.InterfaceModule;
import cn.tenfell.tools.nocontroller.utilsentity.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.lang.reflect.Method;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

public class ToolsUtils {
    public static List<InterfaceDocEntity> interfaceList = new ArrayList<InterfaceDocEntity>();
    public static String interfaceCreateTime;
    public static void setInterfaceList(List<ServiceCacheData> list){
        String[] conMappings = {"json","jsonp"};
        for(ServiceCacheData serviceCacheData:list){
            InterfaceDocEntity interfaceDocEntity = null;
            List<InterfaceDocChild> interfaceDocChildren = null;
            Object service = serviceCacheData.getService();
            List<Method> methodList = serviceCacheData.getMethods();
            for(Method method:methodList){
                Class<?>[] types = method.getParameterTypes();
                InterfaceDoc interfaceDoc = method.getAnnotation(InterfaceDoc.class);
                boolean hasDoc = interfaceDoc != null && (types.length == 1 && types[0] == PoData.class) || (types.length == 2 && types[0] == HttpServletRequest.class && types[1] == HttpServletResponse.class);
                if(!hasDoc){
                    continue;
                }
                if(interfaceDocEntity == null){
                    interfaceDocEntity = new InterfaceDocEntity();
                    interfaceDocChildren = new ArrayList<InterfaceDocChild>();
                    String moduleName = serviceCacheData.getServiceName();
                    InterfaceModule interfaceModule = service.getClass().getAnnotation(InterfaceModule.class);
                    if(interfaceModule != null && !"".equals(interfaceModule.value())){
                        moduleName = interfaceModule.value();
                    }
                    interfaceDocEntity.setName(moduleName);
                }
                InterfaceDocChild interfaceDocChild = new InterfaceDocChild();
                try{
                    Object returnObj = method.getReturnType().newInstance();
                    interfaceDocChild.setReturnData(JSONUtil.toJsonStr(returnObj));
                }catch (Exception e){
                }
                String interfaceName = method.getName();
                if(interfaceDoc != null && !"".equals(interfaceDoc.name())){
                    interfaceName = interfaceDoc.name();
                }
                interfaceDocChild.setName(interfaceName);
                List<InterfaceParams> interfaceParamsList = new ArrayList<InterfaceParams>();
                String[] params = interfaceDoc.params();
                for(String param:params){
                    if(param == null || "".equals(param.trim())){
                        continue;
                    }
                    String[] paramValues = param.split(interfaceDoc.separator(),3);
                    if(paramValues.length != 3){
                        continue;
                    }
                    InterfaceParams interfaceParams = new InterfaceParams();
                    interfaceParams.setParam(paramValues[0]);
                    interfaceParams.setIsNeed(paramValues[1]);
                    interfaceParams.setParamDesc(paramValues[2]);
                    interfaceParamsList.add(interfaceParams);
                }
                interfaceDocChild.setParams(interfaceParamsList);
                List<String> urlList = new ArrayList<String>();
                if(types.length == 1 && types[0] == PoData.class){
                    //表示要处理的json,jsonp
                    for(String conMapping:conMappings){
                        String mapKey = "/"+conMapping+"/"+serviceCacheData.getServiceName()+"/"+method.getName();
                        urlList.add(mapKey);
                    }
                }else if(types.length == 2 && types[0] == HttpServletRequest.class && types[1] == HttpServletResponse.class){
                    //表示要处理的selevt
                    String mapKey = "/selevt/"+serviceCacheData.getServiceName()+"/"+method.getName();
                    urlList.add(mapKey);
                }
                interfaceDocChild.setUrlList(urlList);
                interfaceDocChildren.add(interfaceDocChild);
            }
            if(interfaceDocEntity != null){
                interfaceDocEntity.setList(interfaceDocChildren);
                interfaceList.add(interfaceDocEntity);
            }
        }
        interfaceCreateTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date());
    }
    public static String getExceptionMessage(Throwable e,boolean isAll) {
        String msg;
        Throwable temp = ExceptionUtil.getRootCause(e);
        if(isAll){
            msg = ExceptionUtil.stacktraceToString(temp);
        }else{
            msg = temp.getMessage();
        }
        return msg;
    }
    public static PoData readRequestData(HttpServletRequest request){
        PoData poData = PoData.create();
        String requestBody = ServletUtil.getBody(request);
        poData.putAll(ServletUtil.getParamMap(request));
        if(StrUtil.isNotBlank(requestBody)){
            poData.put("requestBody",requestBody);
        }
        return poData;
    }
    public static <T> T dataToBean(PoData data,Class clazz){
        try{
            String requestBody = data.getStr("requestBody");
            if(StrUtil.isNotBlank(requestBody)){
                data = JSONUtil.parseObj(requestBody).toBean(PoData.class);
            }
            return (T)data.toBean(clazz);
        }catch (Exception e){
            return null;
        }
    }
}
